// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Rectangle {
    id: thumbnailbar
    color: "#00000000"

    property real cheight: 63

    property int count: 0
    property real item_padding:5

    property real itemHeight: (linear)? itemSml :itemBig
    property real itemWidth:  (linear)? itemSml :itemBig

    property real itemBig: (android)? 192 :160
    property real itemSml: (android)? 92: 92

    property int index_padding: 0

    property real previewWidth: (fullscreen)? 40+width : width
    property real previewHeight: (fullscreen)? 40+height : height
    property real previewX: (fullscreen)? -20 : 0
    property real previewY: (fullscreen)? -20 : 0

    property bool fancy: true
    property bool fullscreen: false
    property bool animations_on: true

    property int on_preview : -1

    property bool linear: (on_preview != -1)
    property real list_width: (linear && virtual_width>width)?   virtual_width: width;
    property real list_height:(linear || virtual_height<height)? height : virtual_height;
    property real list_x: 0
    property real list_y: 0

    property real virtual_height: itemHeight*Math.floor( (count+index_padding-1) / items_per_line )
    property real virtual_width:  (itemWidth+item_padding)*count

    property int items_per_line: Math.floor( thumbnailbar.list_width/(thumbnailbar.itemWidth+thumbnailbar.item_padding) )

    signal preview( int index )

    onOn_previewChanged: {
        if( on_preview === -1 )
            fullscreen = false
    }

    onFullscreenChanged: {
        if( fullscreen )
            anim_disabler_timer.running = true
        else
            animations_on = true
    }

    Timer {
        id: anim_disabler_timer
        interval: 1000
        running: false
        repeat: false
        onTriggered: animations_on = !fullscreen
    }

    function add(){
        var component = Qt.createComponent("ThumbnailBarItem.qml");
        var item = component.createObject(thumbnailbar);
        main.help = false
        return item
    }

    function next(){
        thumbnailbar.on_preview++
        if( thumbnailbar.on_preview == thumbnailbar.count )
            thumbnailbar.on_preview = -1

        thumbnailbar.fancy = false
        thumbnailbar.preview( thumbnailbar.on_preview )
        thumbnailbar.fancy = true
    }

    function previous(){
        if( thumbnailbar.on_preview == -1 )
            return

        thumbnailbar.fancy = false
        thumbnailbar.on_preview--
        thumbnailbar.preview( thumbnailbar.on_preview )
        thumbnailbar.fancy = true
    }

    ThumbnailBarButton {
        id: fullscreen_button
        anchors.left: thumbnailbar.left
        anchors.bottom: thumbnailbar.bottom
        text: qsTr("FullScreen")
        z: 101
        anchors.bottomMargin: (thumbnailbar.linear && !fullscreen)?thumbnailbar.itemHeight+3:3
        visible: (on_preview != -1 && android)
        onClicked: fullscreen = !fullscreen
    }

    ThumbnailBarButton {
        id: prev_button
        anchors.left: thumbnailbar.left
        anchors.bottom: thumbnailbar.bottom
        text: qsTr("Previous")
        z: 101
        visible: (on_preview != -1 && !android)
        anchors.bottomMargin: (thumbnailbar.linear && !fullscreen)?thumbnailbar.itemHeight+3:3
        onClicked: previous()
    }

    ThumbnailBarButton {
        id: next_button
        anchors.right: thumbnailbar.right
        anchors.bottom: thumbnailbar.bottom
        text: qsTr("Next")
        z: 101
        visible: (on_preview != -1 && !android)
        anchors.bottomMargin: (thumbnailbar.linear && !fullscreen)?thumbnailbar.itemHeight+3:3
        onClicked: next()
    }

    ThumbnailBarButton{
        id: help_button
        text: qsTr("Help")
        z: 101
        visible: (on_preview != -1 && !android)
        anchors.top: thumbnailbar.top
        anchors.left: thumbnailbar.left
        onClicked: help = !help
    }
}
